==> bootstrap_storybook-8.x-2.4.tar.gz: bootstrap_storybook/src/kits/default/webpack.mix.js <==
/*
 |--------------------------------------------------------------------------
 | Mix Asset Management
 |--------------------------------------------------------------------------
 |
 | Mix provides a clean, fluent API for defining some Webpack build steps
 | for your application. See https://github.com/JeffreyWay/laravel-mix.
 |
 */
// Imports the proxy from config.js to avoid conflicts
let mix = require('laravel-mix');
let proxy = require('./config/config.js');
require('laravel-mix-copy-watched');

/*
 |--------------------------------------------------------------------------
 | Configuration
 |--------------------------------------------------------------------------
 */
mix
  .setPublicPath('assets')
  .disableNotifications()
  .options({
    processCssUrls: false
  });

/*
 |--------------------------------------------------------------------------
 | Browsersync
 |--------------------------------------------------------------------------
 */
mix.browserSync({
  proxy: proxy.proxy,
  files: ['assets/js/**/*.js', 'assets/css/**/*.css'],
  stream: true,
});

/*
 |--------------------------------------------------------------------------
 | SASS
 |--------------------------------------------------------------------------
 */
// General CSS file
mix.sass('src/sass/BOOTSTRAP_STORYBOOK_SUBTHEME_MACHINE_NAME.style.scss', 'css');

/*
 |--------------------------------------------------------------------------
 | JS
 |--------------------------------------------------------------------------
 */
mix.js('src/js/BOOTSTRAP_STORYBOOK_SUBTHEME_MACHINE_NAME.script.js', 'js');

/*
 |--------------------------------------------------------------------------
 | IMAGES / ICONS
 |--------------------------------------------------------------------------
 */
// Directly copies the image or the icon, does not do anything on the image
mix.copyDirectoryWatched('src/images', 'assets/images');
mix.copyDirectoryWatched('src/icons', 'assets/icons');

==> bootstrap_storybook-8.x-2.7.tar.gz: bootstrap_storybook/src/kits/default/webpack.mix.js <==
/*
 |--------------------------------------------------------------------------
 | Mix Asset Management
 |--------------------------------------------------------------------------
 |
 | Mix provides a clean, fluent API for defining some Webpack build steps
 | for your application. See https://github.com/JeffreyWay/laravel-mix.
 |
 */
// Imports the proxy from config.js to avoid conflicts
let mix = require('laravel-mix');
let proxy = require('./config/config.js');
require('laravel-mix-copy-watched');

/*
 |--------------------------------------------------------------------------
 | Configuration
 |--------------------------------------------------------------------------
 */
mix
  .setPublicPath('assets')
  .disableNotifications()
  .options({
    processCssUrls: false
  });

/*
 |--------------------------------------------------------------------------
 | Browsersync
 |--------------------------------------------------------------------------
 */
mix.browserSync({
  proxy: proxy.proxy,
  files: ['assets/js/**/*.js', 'assets/css/**/*.css', 'assets/components/**/*.css', 'assets/components/**/*.js'],
  stream: true,
});

/*
 |--------------------------------------------------------------------------
 | SASS
 |--------------------------------------------------------------------------
 */
// General CSS file
mix.sass('src/sass/BOOTSTRAP_STORYBOOK_SUBTHEME_MACHINE_NAME.style.scss', 'css');

/*
 |--------------------------------------------------------------------------
 | JS
 |--------------------------------------------------------------------------
 */
mix.js('src/js/BOOTSTRAP_STORYBOOK_SUBTHEME_MACHINE_NAME.script.js', 'js');

/*
 |--------------------------------------------------------------------------
 | IMAGES / ICONS
 |--------------------------------------------------------------------------
 */
// Directly copies the image or the icon, does not do anything on the image
mix.copyDirectoryWatched('src/images', 'assets/images');
mix.copyDirectoryWatched('src/icons', 'assets/icons');
